==> DKS-1.1.0.tar.gz: dks/src/Algorithms/CollimatorPhysics.h <==
#ifndef H_COLLIMATOR_PHYSICS
#define H_COLLIMATOR_PHYSICS

#include <iostream>
#include <string>
#include "../DKSDefinitions.h"

class DKSCollimatorPhysics {

protected:

  int numBlocks_m;
  int blockSize_m;

public:
  
  virtual ~DKSCollimatorPhysics() { }
  
  virtual int CollimatorPhysics(void *mem_ptr, void *par_ptr, int numpartices) = 0;

  virtual int CollimatorPhysicsSoA(void *label_ptr, void *localID_ptr, 
				   void *rx_ptr, void *ry_ptr, void *rz_ptr, 
				   void *px_ptr, void *py_ptr, void *pz_ptr,
				   void *par_ptr, int numparticles) = 0;
  
  virtual int CollimatorPhysicsSort(void *mem_ptr, int numparticles, int &numaddback) = 0;

  virtual int CollimatorPhysicsSortSoA(void *label_ptr, void *localID_ptr, 
				       void *rx_ptr, void *ry_ptr, void *rz_ptr, 
				       void *px_ptr, void *py_ptr, void *pz_ptr,
				       void *par_ptr, int numparticles, int &numaddback) = 0;

  virtual int ParallelTTrackerPush(void *r_ptr, void *p_ptr, int npart, void *dt_ptr, 
				   double dt, double c, bool usedt = false, int streamId = -1) = 0;

  virtual int ParallelTTrackerKick(void *r_ptr, void *p_ptr, void *ef_ptr,
				   void *bf_ptr, void *dt_ptr, double charge,
				   double mass, int npart, double c, int streamId = -1) = 0; 

  virtual int ParallelTTrackerPushTransform(void *x_ptr, void *p_ptr, void *lastSec_ptr, 
					    void *orient_ptr, int npart, int nsec, void *dt_ptr, 
					    double dt, double c, bool usedt = false, 
					    int streamId = -1) = 0;


};

#endif

==> DKS-1.1.2.tar.gz: dks/src/Algorithms/CollimatorPhysics.h <==
#ifndef H_COLLIMATOR_PHYSICS
#define H_COLLIMATOR_PHYSICS

#include <iostream>
#include <string>
#include "../DKSDefinitions.h"

class DKSCollimatorPhysics {

protected:

  int numBlocks_m;
  int blockSize_m;

public:
  
  virtual ~DKSCollimatorPhysics() { }
  
  virtual int CollimatorPhysics(void *mem_ptr, void *par_ptr, int numpartices, 
				bool enableRutherforScattering = true) = 0;

  virtual int CollimatorPhysicsSoA(void *label_ptr, void *localID_ptr, 
				   void *rx_ptr, void *ry_ptr, void *rz_ptr, 
				   void *px_ptr, void *py_ptr, void *pz_ptr,
				   void *par_ptr, int numparticles) = 0;
  
  virtual int CollimatorPhysicsSort(void *mem_ptr, int numparticles, int &numaddback) = 0;

  virtual int CollimatorPhysicsSortSoA(void *label_ptr, void *localID_ptr, 
				       void *rx_ptr, void *ry_ptr, void *rz_ptr, 
				       void *px_ptr, void *py_ptr, void *pz_ptr,
				       void *par_ptr, int numparticles, int &numaddback) = 0;

  virtual int ParallelTTrackerPush(void *r_ptr, void *p_ptr, int npart, void *dt_ptr, 
				   double dt, double c, bool usedt = false, int streamId = -1) = 0;

  virtual int ParallelTTrackerKick(void *r_ptr, void *p_ptr, void *ef_ptr,
				   void *bf_ptr, void *dt_ptr, double charge,
				   double mass, int npart, double c, int streamId = -1) = 0; 

  virtual int ParallelTTrackerPushTransform(void *x_ptr, void *p_ptr, void *lastSec_ptr, 
					    void *orient_ptr, int npart, int nsec, void *dt_ptr, 
					    double dt, double c, bool usedt = false, 
					    int streamId = -1) = 0;


};

#endif
